/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
export interface PatchPagesPageIdIncidents {
    incident?: {
        /**
         * Incident Name. There is a maximum limit of 255 characters.
         */
        name?: string;
        /**
         * The incident status. For realtime incidents, valid values are investigating, identified, monitoring, and resolved. For scheduled incidents, valid values are scheduled, in_progress, verifying, and completed.
         */
        status?: "investigating" | "identified" | "monitoring" | "resolved" | "scheduled" | "in_progress" | "verifying" | "completed";
        /**
         * value to override calculated impact value
         */
        impact_override?: "none" | "maintenance" | "minor" | "major" | "critical";
        /**
         * The timestamp the incident is scheduled for.
         */
        scheduled_for?: string;
        /**
         * The timestamp the incident is scheduled until.
         */
        scheduled_until?: string;
        /**
         * Controls whether to remind subscribers prior to scheduled incidents.
         */
        scheduled_remind_prior?: boolean;
        /**
         * Controls whether change components status to under_maintenance once scheduled maintenance is in progress.
         */
        auto_transition_to_maintenance_state?: boolean;
        /**
         * Controls whether change components status to operational once scheduled maintenance completes.
         */
        auto_transition_to_operational_state?: boolean;
        /**
         * Controls whether the incident is scheduled to automatically change to in progress.
         */
        scheduled_auto_in_progress?: boolean;
        /**
         * Controls whether the incident is scheduled to automatically change to complete.
         */
        scheduled_auto_completed?: boolean;
        /**
         * Controls whether send notification when scheduled maintenances auto transition to started.
         */
        auto_transition_deliver_notifications_at_start?: boolean;
        /**
         * Controls whether send notification when scheduled maintenances auto transition to completed.
         */
        auto_transition_deliver_notifications_at_end?: boolean;
        /**
         * Attach a json object to the incident. All top-level values in the object must also be objects.
         */
        metadata?: any;
        /**
         * Deliver notifications to subscribers if this is true. If this is false, create an incident without notifying customers.
         */
        deliver_notifications?: boolean;
        /**
         * Controls whether tweet automatically when scheduled maintenance starts.
         */
        auto_tweet_at_beginning?: boolean;
        /**
         * Controls whether tweet automatically when scheduled maintenance completes.
         */
        auto_tweet_on_completion?: boolean;
        /**
         * Controls whether tweet automatically when scheduled maintenance is created.
         */
        auto_tweet_on_creation?: boolean;
        /**
         * Controls whether tweet automatically one hour before scheduled maintenance starts.
         */
        auto_tweet_one_hour_before?: boolean;
        /**
         * TimeStamp when incident was backfilled.
         */
        backfill_date?: string;
        /**
         * Controls whether incident is backfilled. If true, components cannot be specified.
         */
        backfilled?: boolean;
        /**
         * The initial message, created as the first incident update. There is a maximum limit of 25000 characters
         */
        body?: string;
        /**
         * Map of status changes to apply to affected components
         */
        components?: {
            /**
             * Map of status changes to apply to affected components
             */
            m2lzwfwx4x90?: "operational" | "under_maintenance" | "degraded_performance" | "partial_outage" | "major_outage" | "";
        };
        /**
         * List of component_ids affected by this incident
         */
        component_ids?: Array<string>;
        /**
         * Same as :scheduled_auto_transition_in_progress. Controls whether the incident is scheduled to automatically change to in progress.
         */
        scheduled_auto_transition?: boolean;
    };
}
//# sourceMappingURL=PatchPagesPageIdIncidents.d.ts.map