/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { GetPagesRequest, GetPagesResponseOK } from "./types/page";
import { UpdatePageRequest, UpdatePageResponseOK } from "./types/page";
import { GetPageRequest, GetPageResponseOK } from "./types/page";
import { UpdateIncidentUpdateRequest, UpdateIncidentUpdateResponseOK } from "./types/incident/update";
import { CreateIncidentRequest, CreateIncidentResponseOK } from "./types/incident";
import { GetIncidentsRequest, GetIncidentsResponseOK } from "./types/incident";
import { GetIncidentActiveMaintenancesRequest, GetIncidentActiveMaintenancesResponseOK } from "./types/incident";
import { GetUpcomingIncidentsRequest, GetUpcomingIncidentsResponseOK } from "./types/incident";
import { GetScheduledIncidentsRequest, GetScheduledIncidentsResponseOK } from "./types/incident";
import { GetUnresolvedIncidentsRequest, GetUnresolvedIncidentsResponseOK } from "./types/incident";
import { DeleteIncidentRequest, DeleteIncidentResponseOK } from "./types/incident";
import { UpdateIncidentRequest, UpdateIncidentResponseOK } from "./types/incident";
import { GetIncidentRequest, GetIncidentResponseOK } from "./types/incident";
import { CreateComponentRequest, CreateComponentResponseOK } from "./types/component";
import { GetComponentsRequest, GetComponentsResponseOK } from "./types/component";
import { UpdateComponentRequest, UpdateComponentResponseOK } from "./types/component";
import { DeleteComponentRequest, DeleteComponentResponseOK } from "./types/component";
import { GetComponentRequest, GetComponentResponseOK } from "./types/component";
import { GetComponentUptimeDataRequest, GetComponentUptimeDataResponseOK } from "./types/component";
import { RemoveComponentPageAccessUsersRequest, RemoveComponentPageAccessUsersResponseOK } from "./types/component";
import { AddComponentPageAccessUsersRequest, AddComponentPageAccessUsersResponseOK } from "./types/component";
import { RemoveComponentPageAccessGroupsRequest, RemoveComponentPageAccessGroupsResponseOK } from "./types/component";
import { AddComponentPageAccessGroupsRequest, AddComponentPageAccessGroupsResponseOK } from "./types/component";
import { GetUserPermissionsRequest, GetUserPermissionsResponseOK } from "./types/user";
import { DeleteUserRequest, DeleteUserResponseOK } from "./types/user";
import { CreateUserRequest, CreateUserResponseOK } from "./types/user";
import { GetUsersRequest, GetUsersResponseOK } from "./types/user";
import { BaseApiCore, Headers, Response, ErrorStrategyOptionType, PlatformImplementation } from "@managed-api/commons-core";
import { CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyOption } from "./errorStrategy";
import { ErrorStrategyBuilder } from "./builders/errorStrategy";
export interface StatuspageApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class StatuspageApiCore extends BaseApiCore {
    private options?;
    Page: PageGroup;
    Incident: IncidentGroup;
    Component: ComponentGroup;
    User: UserGroup;
    All: AllGroup;
    constructor(options?: StatuspageApiCoreOptions | undefined);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private Page;
    private Incident;
    private Component;
    private User;
    constructor(Page: PageGroup, Incident: IncidentGroup, Component: ComponentGroup, User: UserGroup);
    /**
     * Get a list of pages
     * Alternative usage: Page.getPages
     * Documentation: https://developer.statuspage.io/#operation/getPages
     * @param options Request options.
     */
    getPages<T = GetPagesResponseOK>(options?: GetPagesRequest): Promise<GetPagesResponseOK | T>;
    /**
     * Update a page
     * Alternative usage: Page.updatePage
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageId
     * @param options Request options.
     */
    updatePage<T = UpdatePageResponseOK>(options: UpdatePageRequest): Promise<UpdatePageResponseOK | T>;
    /**
     * Get a page
     * Alternative usage: Page.getPage
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageId
     * @param options Request options.
     */
    getPage<T = GetPageResponseOK>(options: GetPageRequest): Promise<GetPageResponseOK | T>;
    /**
     * Create an incident
     * Alternative usage: Incident.createIncident
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdIncidents
     * @param options Request options.
     */
    createIncident<T = CreateIncidentResponseOK>(options: CreateIncidentRequest): Promise<CreateIncidentResponseOK | T>;
    /**
     * Get a list of incidents
     * Alternative usage: Incident.getIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidents
     * @param options Request options.
     */
    getIncidents<T = GetIncidentsResponseOK>(options: GetIncidentsRequest): Promise<GetIncidentsResponseOK | T>;
    /**
     * Get a list of active maintenances
     * Alternative usage: Incident.getActiveMaintenances
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsActiveMaintenance
     * @param options Request options.
     */
    getIncidentActiveMaintenances<T = GetIncidentActiveMaintenancesResponseOK>(options: GetIncidentActiveMaintenancesRequest): Promise<GetIncidentActiveMaintenancesResponseOK | T>;
    /**
     * Get a list of upcoming incidents
     * Alternative usage: Incident.getUpcomingIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUpcoming
     * @param options Request options.
     */
    getUpcomingIncidents<T = GetUpcomingIncidentsResponseOK>(options: GetUpcomingIncidentsRequest): Promise<GetUpcomingIncidentsResponseOK | T>;
    /**
     * Get a list of scheduled incidents
     * Alternative usage: Incident.getScheduledIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsScheduled
     * @param options Request options.
     */
    getScheduledIncidents<T = GetScheduledIncidentsResponseOK>(options: GetScheduledIncidentsRequest): Promise<GetScheduledIncidentsResponseOK | T>;
    /**
     * Get a list of unresolved incidents
     * Alternative usage: Incident.getUnresolvedIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUnresolved
     * @param options Request options.
     */
    getUnresolvedIncidents<T = GetUnresolvedIncidentsResponseOK>(options: GetUnresolvedIncidentsRequest): Promise<GetUnresolvedIncidentsResponseOK | T>;
    /**
     * Delete an incident
     * Alternative usage: Incident.deleteIncident
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    deleteIncident<T = DeleteIncidentResponseOK>(options: DeleteIncidentRequest): Promise<DeleteIncidentResponseOK | T>;
    /**
     * Update an incident
     * Alternative usage: Incident.updateIncident
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    updateIncident<T = UpdateIncidentResponseOK>(options: UpdateIncidentRequest): Promise<UpdateIncidentResponseOK | T>;
    /**
     * Get an incident
     * Alternative usage: Incident.getIncident
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    getIncident<T = GetIncidentResponseOK>(options: GetIncidentRequest): Promise<GetIncidentResponseOK | T>;
    /**
     * Update a previous incident update
     * Alternative usage: Incident.Update.updateIncidentUpdate
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentIdIncidentUpdatesIncidentUpdateId
     * @param options Request options.
     */
    updateIncidentUpdate<T = UpdateIncidentUpdateResponseOK>(options: UpdateIncidentUpdateRequest): Promise<UpdateIncidentUpdateResponseOK | T>;
    /**
     * Create a component
     * Alternative usage: Component.createComponent
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponents
     * @param options Request options.
     */
    createComponent<T = CreateComponentResponseOK>(options: CreateComponentRequest): Promise<CreateComponentResponseOK | T>;
    /**
     * Get a list of components
     * Alternative usage: Component.getComponents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponents
     * @param options Request options.
     */
    getComponents<T = GetComponentsResponseOK>(options: GetComponentsRequest): Promise<GetComponentsResponseOK | T>;
    /**
     * If group_id is "null" then the component will be removed from a group.
     * Alternative usage: Component.updateComponent
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    updateComponent<T = UpdateComponentResponseOK>(options: UpdateComponentRequest): Promise<UpdateComponentResponseOK | T>;
    /**
     * Delete a component
     * Alternative usage: Component.deleteComponent
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentId
     * @param options Request options.
     */
    deleteComponent<T = DeleteComponentResponseOK>(options: DeleteComponentRequest): Promise<DeleteComponentResponseOK | T>;
    /**
     * Get a component
     * Alternative usage: Component.getComponent
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    getComponent<T = GetComponentResponseOK>(options: GetComponentRequest): Promise<GetComponentResponseOK | T>;
    /**
     * Get uptime data for a component that has uptime showcase enabled
     * Alternative usage: Component.getUptimeData
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentIdUptime
     * @param options Request options.
     */
    getComponentUptimeData<T = GetComponentUptimeDataResponseOK>(options: GetComponentUptimeDataRequest): Promise<GetComponentUptimeDataResponseOK | T>;
    /**
     * Remove page access users from component
     * Alternative usage: Component.removePageAccessUsers
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    removeComponentPageAccessUsers<T = RemoveComponentPageAccessUsersResponseOK>(options: RemoveComponentPageAccessUsersRequest): Promise<RemoveComponentPageAccessUsersResponseOK | T>;
    /**
     * Add page access users to a component
     * Alternative usage: Component.addPageAccessUsers
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    addComponentPageAccessUsers<T = AddComponentPageAccessUsersResponseOK>(options: AddComponentPageAccessUsersRequest): Promise<AddComponentPageAccessUsersResponseOK | T>;
    /**
     * Remove page access groups from a component
     * Alternative usage: Component.removePageAccessGroups
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    removeComponentPageAccessGroups<T = RemoveComponentPageAccessGroupsResponseOK>(options: RemoveComponentPageAccessGroupsRequest): Promise<RemoveComponentPageAccessGroupsResponseOK | T>;
    /**
     * Add page access groups to a component
     * Alternative usage: Component.addPageAccessGroups
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    addComponentPageAccessGroups<T = AddComponentPageAccessGroupsResponseOK>(options: AddComponentPageAccessGroupsRequest): Promise<AddComponentPageAccessGroupsResponseOK | T>;
    /**
     * Get a user's permissions
     * Alternative usage: User.getPermissions
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdPermissionsUserId
     * @param options Request options.
     */
    getUserPermissions<T = GetUserPermissionsResponseOK>(options: GetUserPermissionsRequest): Promise<GetUserPermissionsResponseOK | T>;
    /**
     * Delete a user
     * Alternative usage: User.deleteUser
     * Documentation: https://developer.statuspage.io/#operation/deleteOrganizationsOrganizationIdUsersUserId
     * @param options Request options.
     */
    deleteUser<T = DeleteUserResponseOK>(options: DeleteUserRequest): Promise<DeleteUserResponseOK | T>;
    /**
     * Create a user
     * Alternative usage: User.createUser
     * Documentation: https://developer.statuspage.io/#operation/postOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    createUser<T = CreateUserResponseOK>(options: CreateUserRequest): Promise<CreateUserResponseOK | T>;
    /**
     * Get a list of users
     * Alternative usage: User.getUsers
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    getUsers<T = GetUsersResponseOK>(options: GetUsersRequest): Promise<GetUsersResponseOK | T>;
}
declare class PageGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get a list of pages
     * Documentation: https://developer.statuspage.io/#operation/getPages
     * @param options Request options.
     */
    getPages<T = GetPagesResponseOK>(options?: GetPagesRequest): Promise<GetPagesResponseOK | T>;
    /**
     * Update a page
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageId
     * @param options Request options.
     */
    updatePage<T = UpdatePageResponseOK>(options: UpdatePageRequest): Promise<UpdatePageResponseOK | T>;
    /**
     * Get a page
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageId
     * @param options Request options.
     */
    getPage<T = GetPageResponseOK>(options: GetPageRequest): Promise<GetPageResponseOK | T>;
}
declare class IncidentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    Update: IncidentUpdateGroup;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create an incident
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdIncidents
     * @param options Request options.
     */
    createIncident<T = CreateIncidentResponseOK>(options: CreateIncidentRequest): Promise<CreateIncidentResponseOK | T>;
    /**
     * Get a list of incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidents
     * @param options Request options.
     */
    getIncidents<T = GetIncidentsResponseOK>(options: GetIncidentsRequest): Promise<GetIncidentsResponseOK | T>;
    /**
     * Get a list of active maintenances
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsActiveMaintenance
     * @param options Request options.
     */
    getActiveMaintenances<T = GetIncidentActiveMaintenancesResponseOK>(options: GetIncidentActiveMaintenancesRequest): Promise<GetIncidentActiveMaintenancesResponseOK | T>;
    /**
     * Get a list of upcoming incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUpcoming
     * @param options Request options.
     */
    getUpcomingIncidents<T = GetUpcomingIncidentsResponseOK>(options: GetUpcomingIncidentsRequest): Promise<GetUpcomingIncidentsResponseOK | T>;
    /**
     * Get a list of scheduled incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsScheduled
     * @param options Request options.
     */
    getScheduledIncidents<T = GetScheduledIncidentsResponseOK>(options: GetScheduledIncidentsRequest): Promise<GetScheduledIncidentsResponseOK | T>;
    /**
     * Get a list of unresolved incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUnresolved
     * @param options Request options.
     */
    getUnresolvedIncidents<T = GetUnresolvedIncidentsResponseOK>(options: GetUnresolvedIncidentsRequest): Promise<GetUnresolvedIncidentsResponseOK | T>;
    /**
     * Delete an incident
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    deleteIncident<T = DeleteIncidentResponseOK>(options: DeleteIncidentRequest): Promise<DeleteIncidentResponseOK | T>;
    /**
     * Update an incident
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    updateIncident<T = UpdateIncidentResponseOK>(options: UpdateIncidentRequest): Promise<UpdateIncidentResponseOK | T>;
    /**
     * Get an incident
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    getIncident<T = GetIncidentResponseOK>(options: GetIncidentRequest): Promise<GetIncidentResponseOK | T>;
}
declare class IncidentUpdateGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Update a previous incident update
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentIdIncidentUpdatesIncidentUpdateId
     * @param options Request options.
     */
    updateIncidentUpdate<T = UpdateIncidentUpdateResponseOK>(options: UpdateIncidentUpdateRequest): Promise<UpdateIncidentUpdateResponseOK | T>;
}
declare class ComponentGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Create a component
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponents
     * @param options Request options.
     */
    createComponent<T = CreateComponentResponseOK>(options: CreateComponentRequest): Promise<CreateComponentResponseOK | T>;
    /**
     * Get a list of components
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponents
     * @param options Request options.
     */
    getComponents<T = GetComponentsResponseOK>(options: GetComponentsRequest): Promise<GetComponentsResponseOK | T>;
    /**
     * If group_id is "null" then the component will be removed from a group.
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    updateComponent<T = UpdateComponentResponseOK>(options: UpdateComponentRequest): Promise<UpdateComponentResponseOK | T>;
    /**
     * Delete a component
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentId
     * @param options Request options.
     */
    deleteComponent<T = DeleteComponentResponseOK>(options: DeleteComponentRequest): Promise<DeleteComponentResponseOK | T>;
    /**
     * Get a component
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    getComponent<T = GetComponentResponseOK>(options: GetComponentRequest): Promise<GetComponentResponseOK | T>;
    /**
     * Get uptime data for a component that has uptime showcase enabled
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentIdUptime
     * @param options Request options.
     */
    getUptimeData<T = GetComponentUptimeDataResponseOK>(options: GetComponentUptimeDataRequest): Promise<GetComponentUptimeDataResponseOK | T>;
    /**
     * Remove page access users from component
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    removePageAccessUsers<T = RemoveComponentPageAccessUsersResponseOK>(options: RemoveComponentPageAccessUsersRequest): Promise<RemoveComponentPageAccessUsersResponseOK | T>;
    /**
     * Add page access users to a component
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    addPageAccessUsers<T = AddComponentPageAccessUsersResponseOK>(options: AddComponentPageAccessUsersRequest): Promise<AddComponentPageAccessUsersResponseOK | T>;
    /**
     * Remove page access groups from a component
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    removePageAccessGroups<T = RemoveComponentPageAccessGroupsResponseOK>(options: RemoveComponentPageAccessGroupsRequest): Promise<RemoveComponentPageAccessGroupsResponseOK | T>;
    /**
     * Add page access groups to a component
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    addPageAccessGroups<T = AddComponentPageAccessGroupsResponseOK>(options: AddComponentPageAccessGroupsRequest): Promise<AddComponentPageAccessGroupsResponseOK | T>;
}
declare class UserGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Get a user's permissions
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdPermissionsUserId
     * @param options Request options.
     */
    getPermissions<T = GetUserPermissionsResponseOK>(options: GetUserPermissionsRequest): Promise<GetUserPermissionsResponseOK | T>;
    /**
     * Delete a user
     * Documentation: https://developer.statuspage.io/#operation/deleteOrganizationsOrganizationIdUsersUserId
     * @param options Request options.
     */
    deleteUser<T = DeleteUserResponseOK>(options: DeleteUserRequest): Promise<DeleteUserResponseOK | T>;
    /**
     * Create a user
     * Documentation: https://developer.statuspage.io/#operation/postOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    createUser<T = CreateUserResponseOK>(options: CreateUserRequest): Promise<CreateUserResponseOK | T>;
    /**
     * Get a list of users
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    getUsers<T = GetUsersResponseOK>(options: GetUsersRequest): Promise<GetUsersResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map