/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class StatuspageApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Page = new PageGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Incident = new IncidentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Component = new ComponentGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Page, this.Incident, this.Component, this.User);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Page, Incident, Component, User) {
        this.Page = Page;
        this.Incident = Incident;
        this.Component = Component;
        this.User = User;
    }
    /**
     * Get a list of pages
     * Alternative usage: Page.getPages
     * Documentation: https://developer.statuspage.io/#operation/getPages
     * @param options Request options.
     */
    async getPages(options) {
        return this.Page.getPages(options);
    }
    /**
     * Update a page
     * Alternative usage: Page.updatePage
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageId
     * @param options Request options.
     */
    async updatePage(options) {
        return this.Page.updatePage(options);
    }
    /**
     * Get a page
     * Alternative usage: Page.getPage
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageId
     * @param options Request options.
     */
    async getPage(options) {
        return this.Page.getPage(options);
    }
    /**
     * Create an incident
     * Alternative usage: Incident.createIncident
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdIncidents
     * @param options Request options.
     */
    async createIncident(options) {
        return this.Incident.createIncident(options);
    }
    /**
     * Get a list of incidents
     * Alternative usage: Incident.getIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidents
     * @param options Request options.
     */
    async getIncidents(options) {
        return this.Incident.getIncidents(options);
    }
    /**
     * Get a list of active maintenances
     * Alternative usage: Incident.getActiveMaintenances
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsActiveMaintenance
     * @param options Request options.
     */
    async getIncidentActiveMaintenances(options) {
        return this.Incident.getActiveMaintenances(options);
    }
    /**
     * Get a list of upcoming incidents
     * Alternative usage: Incident.getUpcomingIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUpcoming
     * @param options Request options.
     */
    async getUpcomingIncidents(options) {
        return this.Incident.getUpcomingIncidents(options);
    }
    /**
     * Get a list of scheduled incidents
     * Alternative usage: Incident.getScheduledIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsScheduled
     * @param options Request options.
     */
    async getScheduledIncidents(options) {
        return this.Incident.getScheduledIncidents(options);
    }
    /**
     * Get a list of unresolved incidents
     * Alternative usage: Incident.getUnresolvedIncidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUnresolved
     * @param options Request options.
     */
    async getUnresolvedIncidents(options) {
        return this.Incident.getUnresolvedIncidents(options);
    }
    /**
     * Delete an incident
     * Alternative usage: Incident.deleteIncident
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    async deleteIncident(options) {
        return this.Incident.deleteIncident(options);
    }
    /**
     * Update an incident
     * Alternative usage: Incident.updateIncident
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    async updateIncident(options) {
        return this.Incident.updateIncident(options);
    }
    /**
     * Get an incident
     * Alternative usage: Incident.getIncident
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    async getIncident(options) {
        return this.Incident.getIncident(options);
    }
    /**
     * Update a previous incident update
     * Alternative usage: Incident.Update.updateIncidentUpdate
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentIdIncidentUpdatesIncidentUpdateId
     * @param options Request options.
     */
    async updateIncidentUpdate(options) {
        return this.Incident.Update.updateIncidentUpdate(options);
    }
    /**
     * Create a component
     * Alternative usage: Component.createComponent
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponents
     * @param options Request options.
     */
    async createComponent(options) {
        return this.Component.createComponent(options);
    }
    /**
     * Get a list of components
     * Alternative usage: Component.getComponents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponents
     * @param options Request options.
     */
    async getComponents(options) {
        return this.Component.getComponents(options);
    }
    /**
     * If group_id is "null" then the component will be removed from a group.
     * Alternative usage: Component.updateComponent
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    async updateComponent(options) {
        return this.Component.updateComponent(options);
    }
    /**
     * Delete a component
     * Alternative usage: Component.deleteComponent
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentId
     * @param options Request options.
     */
    async deleteComponent(options) {
        return this.Component.deleteComponent(options);
    }
    /**
     * Get a component
     * Alternative usage: Component.getComponent
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    async getComponent(options) {
        return this.Component.getComponent(options);
    }
    /**
     * Get uptime data for a component that has uptime showcase enabled
     * Alternative usage: Component.getUptimeData
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentIdUptime
     * @param options Request options.
     */
    async getComponentUptimeData(options) {
        return this.Component.getUptimeData(options);
    }
    /**
     * Remove page access users from component
     * Alternative usage: Component.removePageAccessUsers
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    async removeComponentPageAccessUsers(options) {
        return this.Component.removePageAccessUsers(options);
    }
    /**
     * Add page access users to a component
     * Alternative usage: Component.addPageAccessUsers
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    async addComponentPageAccessUsers(options) {
        return this.Component.addPageAccessUsers(options);
    }
    /**
     * Remove page access groups from a component
     * Alternative usage: Component.removePageAccessGroups
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    async removeComponentPageAccessGroups(options) {
        return this.Component.removePageAccessGroups(options);
    }
    /**
     * Add page access groups to a component
     * Alternative usage: Component.addPageAccessGroups
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    async addComponentPageAccessGroups(options) {
        return this.Component.addPageAccessGroups(options);
    }
    /**
     * Get a user's permissions
     * Alternative usage: User.getPermissions
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdPermissionsUserId
     * @param options Request options.
     */
    async getUserPermissions(options) {
        return this.User.getPermissions(options);
    }
    /**
     * Delete a user
     * Alternative usage: User.deleteUser
     * Documentation: https://developer.statuspage.io/#operation/deleteOrganizationsOrganizationIdUsersUserId
     * @param options Request options.
     */
    async deleteUser(options) {
        return this.User.deleteUser(options);
    }
    /**
     * Create a user
     * Alternative usage: User.createUser
     * Documentation: https://developer.statuspage.io/#operation/postOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    async createUser(options) {
        return this.User.createUser(options);
    }
    /**
     * Get a list of users
     * Alternative usage: User.getUsers
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
}
class PageGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get a list of pages
     * Documentation: https://developer.statuspage.io/#operation/getPages
     * @param options Request options.
     */
    async getPages(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/v1/pages`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update a page
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageId
     * @param options Request options.
     */
    async updatePage(options) {
        const { body, headers, errorStrategy, page_id } = options;
        const request = new Request("PATCH", `/v1/pages/${encodeURIComponent(page_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a page
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageId
     * @param options Request options.
     */
    async getPage(options) {
        const { headers, errorStrategy, page_id } = options;
        const request = new Request("GET", `/v1/pages/${encodeURIComponent(page_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Update = new IncidentUpdateGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Create an incident
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdIncidents
     * @param options Request options.
     */
    async createIncident(options) {
        const { body, headers, errorStrategy, page_id } = options;
        const request = new Request("POST", `/v1/pages/${encodeURIComponent(page_id)}/incidents`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidents
     * @param options Request options.
     */
    async getIncidents(options) {
        const { headers, errorStrategy, page_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/incidents`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of active maintenances
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsActiveMaintenance
     * @param options Request options.
     */
    async getActiveMaintenances(options) {
        const { headers, errorStrategy, page_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/incidents/active_maintenance`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of upcoming incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUpcoming
     * @param options Request options.
     */
    async getUpcomingIncidents(options) {
        const { headers, errorStrategy, page_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/incidents/upcoming`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of scheduled incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsScheduled
     * @param options Request options.
     */
    async getScheduledIncidents(options) {
        const { headers, errorStrategy, page_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/incidents/scheduled`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of unresolved incidents
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsUnresolved
     * @param options Request options.
     */
    async getUnresolvedIncidents(options) {
        const { headers, errorStrategy, page_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/incidents/unresolved`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete an incident
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    async deleteIncident(options) {
        const { headers, errorStrategy, page_id, incident_id } = options;
        const request = new Request("DELETE", `/v1/pages/${encodeURIComponent(page_id)}/incidents/${encodeURIComponent(incident_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update an incident
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    async updateIncident(options) {
        const { body, headers, errorStrategy, page_id, incident_id } = options;
        const request = new Request("PATCH", `/v1/pages/${encodeURIComponent(page_id)}/incidents/${encodeURIComponent(incident_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get an incident
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdIncidentsIncidentId
     * @param options Request options.
     */
    async getIncident(options) {
        const { headers, errorStrategy, page_id, incident_id } = options;
        const request = new Request("GET", `/v1/pages/${encodeURIComponent(page_id)}/incidents/${encodeURIComponent(incident_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IncidentUpdateGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Update a previous incident update
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdIncidentsIncidentIdIncidentUpdatesIncidentUpdateId
     * @param options Request options.
     */
    async updateIncidentUpdate(options) {
        const { body, headers, errorStrategy, page_id, incident_id, incident_update_id } = options;
        const request = new Request("PATCH", `/v1/pages/${encodeURIComponent(page_id)}/incidents/${encodeURIComponent(incident_id)}/incident_updates/${encodeURIComponent(incident_update_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ComponentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Create a component
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponents
     * @param options Request options.
     */
    async createComponent(options) {
        const { body, headers, errorStrategy, page_id } = options;
        const request = new Request("POST", `/v1/pages/${encodeURIComponent(page_id)}/components`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of components
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponents
     * @param options Request options.
     */
    async getComponents(options) {
        const { headers, errorStrategy, page_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/components`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * If group_id is "null" then the component will be removed from a group.
     * Documentation: https://developer.statuspage.io/#operation/patchPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    async updateComponent(options) {
        const { body, headers, errorStrategy, page_id, component_id } = options;
        const request = new Request("PATCH", `/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a component
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentId
     * @param options Request options.
     */
    async deleteComponent(options) {
        const { headers, errorStrategy, page_id, component_id } = options;
        const request = new Request("DELETE", `/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Get a component
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentId
     * @param options Request options.
     */
    async getComponent(options) {
        const { headers, errorStrategy, page_id, component_id } = options;
        const request = new Request("GET", `/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get uptime data for a component that has uptime showcase enabled
     * Documentation: https://developer.statuspage.io/#operation/getPagesPageIdComponentsComponentIdUptime
     * @param options Request options.
     */
    async getUptimeData(options) {
        const { headers, errorStrategy, page_id, component_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}/uptime`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove page access users from component
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    async removePageAccessUsers(options) {
        const { headers, errorStrategy, page_id, component_id } = options;
        const request = new Request("DELETE", `/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}/page_access_users`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add page access users to a component
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessUsers
     * @param options Request options.
     */
    async addPageAccessUsers(options) {
        const { headers, errorStrategy, page_id, component_id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}/page_access_users`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Remove page access groups from a component
     * Documentation: https://developer.statuspage.io/#operation/deletePagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    async removePageAccessGroups(options) {
        const { headers, errorStrategy, page_id, component_id } = options;
        const request = new Request("DELETE", `/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}/page_access_groups`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Add page access groups to a component
     * Documentation: https://developer.statuspage.io/#operation/postPagesPageIdComponentsComponentIdPageAccessGroups
     * @param options Request options.
     */
    async addPageAccessGroups(options) {
        const { headers, errorStrategy, page_id, component_id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/v1/pages/${encodeURIComponent(page_id)}/components/${encodeURIComponent(component_id)}/page_access_groups`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get a user's permissions
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdPermissionsUserId
     * @param options Request options.
     */
    async getPermissions(options) {
        const { headers, errorStrategy, organization_id, user_id } = options;
        const request = new Request("GET", `/v1/organizations/${encodeURIComponent(organization_id)}/permissions/${encodeURIComponent(user_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete a user
     * Documentation: https://developer.statuspage.io/#operation/deleteOrganizationsOrganizationIdUsersUserId
     * @param options Request options.
     */
    async deleteUser(options) {
        const { headers, errorStrategy, organization_id, user_id } = options;
        const request = new Request("DELETE", `/v1/organizations/${encodeURIComponent(organization_id)}/users/${encodeURIComponent(user_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create a user
     * Documentation: https://developer.statuspage.io/#operation/postOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    async createUser(options) {
        const { body, headers, errorStrategy, organization_id } = options;
        const request = new Request("POST", `/v1/organizations/${encodeURIComponent(organization_id)}/users`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a list of users
     * Documentation: https://developer.statuspage.io/#operation/getOrganizationsOrganizationIdUsers
     * @param options Request options.
     */
    async getUsers(options) {
        const { headers, errorStrategy, organization_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/v1/organizations/${encodeURIComponent(organization_id)}/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map