/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PostPagesPageIdComponents } from "../definitions/PostPagesPageIdComponents";
import { ComponentAsResponse } from "../definitions/ComponentAsResponse";
import { ErrorEntityAsResponse } from "../definitions/ErrorEntityAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PatchPagesPageIdComponents } from "../definitions/PatchPagesPageIdComponents";
import { ComponentUptimeAsResponse } from "../definitions/ComponentUptimeAsResponse";
export interface CreateComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    body: PostPagesPageIdComponents;
}
declare type CreateComponentResponseOKType = ComponentAsResponse;
export interface CreateComponentResponseOK extends CreateComponentResponseOKType {
}
declare type CreateComponentResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface CreateComponentResponseError extends CreateComponentResponseErrorType {
}
export interface GetComponentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Page offset to fetch. Beginning February 28, 2023, this endpoint will return paginated data even if this query parameter is not provided.
     */
    page?: number;
    /**
     * Number of results to return per page. Beginning February 28, 2023, a default and maximum limit of 100 will be imposed and this endpoint will return paginated data even if this query parameter is not provided.
     */
    per_page?: number;
}
declare type GetComponentsResponseOKType = Array<ComponentAsResponse>;
export interface GetComponentsResponseOK extends GetComponentsResponseOKType {
}
declare type GetComponentsResponseErrorType = ErrorEntityAsResponse;
export interface GetComponentsResponseError extends GetComponentsResponseErrorType {
}
export interface UpdateComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
    body: PatchPagesPageIdComponents;
}
declare type UpdateComponentResponseOKType = ComponentAsResponse;
export interface UpdateComponentResponseOK extends UpdateComponentResponseOKType {
}
declare type UpdateComponentResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface UpdateComponentResponseError extends UpdateComponentResponseErrorType {
}
export interface DeleteComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
}
export declare type DeleteComponentResponseOK = undefined;
declare type DeleteComponentResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface DeleteComponentResponseError extends DeleteComponentResponseErrorType {
}
export interface GetComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
}
declare type GetComponentResponseOKType = ComponentAsResponse;
export interface GetComponentResponseOK extends GetComponentResponseOKType {
}
declare type GetComponentResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface GetComponentResponseError extends GetComponentResponseErrorType {
}
export interface GetComponentUptimeDataRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
    /**
    * The start date for uptime calculation (defaults to the component's start_date field or 90 days ago, whichever is more recent).
    The maximum supported date range is six calendar months. If the year is given, the date defaults to the first day of the year.
    If the year and month are given, the start date defaults to the first day of that month.
    The earliest supported date is January 1, 1970.
    
    */
    start?: string;
    /**
    * The end date for uptime calculation (defaults to today in the page's time zone). The maximum supported date range is six calendar months.
    If the year is given, the date defaults to the last day of the year. If the year and month are given, the date defaults to the last day of that month.
    The earliest supported date is January 1, 1970.
    
    */
    end?: string;
}
declare type GetComponentUptimeDataResponseOKType = ComponentUptimeAsResponse;
export interface GetComponentUptimeDataResponseOK extends GetComponentUptimeDataResponseOKType {
}
declare type GetComponentUptimeDataResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface GetComponentUptimeDataResponseError extends GetComponentUptimeDataResponseErrorType {
}
export interface RemoveComponentPageAccessUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
}
declare type RemoveComponentPageAccessUsersResponseOKType = ComponentAsResponse;
export interface RemoveComponentPageAccessUsersResponseOK extends RemoveComponentPageAccessUsersResponseOKType {
}
declare type RemoveComponentPageAccessUsersResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface RemoveComponentPageAccessUsersResponseError extends RemoveComponentPageAccessUsersResponseErrorType {
}
export interface AddComponentPageAccessUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
    /**
     * List of page access users to add to component
     */
    page_access_user_ids: Array<string>;
}
declare type AddComponentPageAccessUsersResponseOKType = ComponentAsResponse;
export interface AddComponentPageAccessUsersResponseOK extends AddComponentPageAccessUsersResponseOKType {
}
declare type AddComponentPageAccessUsersResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface AddComponentPageAccessUsersResponseError extends AddComponentPageAccessUsersResponseErrorType {
}
export interface RemoveComponentPageAccessGroupsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
}
declare type RemoveComponentPageAccessGroupsResponseOKType = ComponentAsResponse;
export interface RemoveComponentPageAccessGroupsResponseOK extends RemoveComponentPageAccessGroupsResponseOKType {
}
declare type RemoveComponentPageAccessGroupsResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface RemoveComponentPageAccessGroupsResponseError extends RemoveComponentPageAccessGroupsResponseErrorType {
}
export interface AddComponentPageAccessGroupsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Page identifier
     */
    page_id: string;
    /**
     * Component identifier
     */
    component_id: string;
    /**
     * List of page access groups to add to component
     */
    page_access_group_ids: Array<string>;
}
declare type AddComponentPageAccessGroupsResponseOKType = ComponentAsResponse;
export interface AddComponentPageAccessGroupsResponseOK extends AddComponentPageAccessGroupsResponseOKType {
}
declare type AddComponentPageAccessGroupsResponseErrorType = ErrorEntityAsResponse & ErrorEntityAsResponse & ErrorEntityAsResponse;
export interface AddComponentPageAccessGroupsResponseError extends AddComponentPageAccessGroupsResponseErrorType {
}
export {};
//# sourceMappingURL=component.d.ts.map